import { useEffect } from 'react';
import { ArrowRight, Cake, ShoppingBag, Star } from 'lucide-react';
import { Link } from 'react-router-dom';

import { useCartStore } from '@/lib/store';

import { Button } from '@/components/ui/button';

export default function Landing() {
  const { initializeCart } = useCartStore();

  useEffect(() => {
    initializeCart();
  }, [initializeCart]);

  const featuredCakes = [
    {
      id: 1,
      name: 'Strawberry Delight',
      description:
        'Fresh strawberries on a vanilla base with cream cheese frosting',
      price: 32.99,
      image:
        'https://www.flurys.com/cdn/shop/products/StrawberryCake_2.jpg?v=1676363157&width=1280',
    },
    {
      id: 2,
      name: 'Chocolate Dream',
      description: 'Rich chocolate cake with ganache and chocolate shavings',
      price: 34.99,
      image:
        'https://www.flurys.com/cdn/shop/products/ChocolateCake_1.jpg?v=1676363155&width=840',
    },
    {
      id: 3,
      name: 'Lemon Sunshine',
      description: 'Zesty lemon cake with lemon curd and buttercream',
      price: 29.99,
      image:
        'https://charlotteslivelykitchen.com/wp-content/uploads/2019/05/lemon-cake-2.jpg',
    },
  ];

  const reviews = [
    {
      name: 'Sophia Patel',
      img: 'https://avatar.iran.liara.run/public/94',
      comment:
        'The cake was absolutely delicious and beautifully decorated. Everyone at the party loved it! Will definitely order again.',
    },
    {
      name: 'Liam Johnson',
      img: 'https://avatar.iran.liara.run/public/25',
      comment:
        'Amazing taste and perfect texture! The custom design was exactly as I imagined. Highly recommended!',
    },
    {
      name: 'Emma Williams',
      img: 'https://avatar.iran.liara.run/public/91',
      comment:
        "Fresh, flavorful, and elegantly crafted. It was the highlight of our celebration. Can't wait to try another one!",
    },
  ];

  return (
    <div className='flex flex-col min-h-screen'>
      <div className='flex-grow'>
        {/* Hero Section */}
        <section className='bg-gradient-to-b from-pink-50 to-yellow-50 py-16 md:py-24'>
          <div className='container mx-auto px-4 md:px-6'>
            <div className='grid grid-cols-1 md:grid-cols-2 gap-8 items-center'>
              <div className='space-y-6'>
                <h1 className='text-4xl md:text-6xl font-bold text-pink-600'>
                  Delicious Cakes for Every Occasion
                </h1>
                <p className='text-lg md:text-xl text-gray-700'>
                  Handcrafted with love, our cakes bring joy to your special
                  moments. Made with premium ingredients for an unforgettable
                  taste experience.
                </p>
                <div className='flex flex-col sm:flex-row gap-4'>
                  <Button
                    asChild
                    className='bg-pink-500 hover:bg-pink-600 text-white rounded-full px-8 py-6 text-lg'
                  >
                    <Link to='/menu'>
                      Order Now <ArrowRight className='ml-2 h-5 w-5' />
                    </Link>
                  </Button>
                  <Button
                    variant='outline'
                    asChild
                    className='border-pink-300 text-pink-600 hover:bg-pink-50 rounded-full px-8 py-6 text-lg'
                  >
                    <Link to='/about'>Our Story</Link>
                  </Button>
                </div>
              </div>
              <div className='relative h-[300px] md:h-[400px] rounded-2xl overflow-hidden'>
                <img
                  src='https://images.pexels.com/photos/2536967/pexels-photo-2536967.jpeg?auto=compress&cs=tinysrgb&w=1260&h=750&dpr=2'
                  alt='Delicious cake showcase'
                  className='object-cover'
                />
              </div>
            </div>
          </div>
        </section>

        {/* Featured Cakes */}
        <section className='py-16 bg-white'>
          <div className='container mx-auto px-4 md:px-6'>
            <div className='text-center mb-12'>
              <h2 className='text-3xl md:text-4xl font-bold text-gray-800 mb-4'>
                Our Featured Cakes
              </h2>
              <p className='text-gray-600 max-w-2xl mx-auto'>
                Discover our most loved creations, each one crafted with care
                and premium ingredients
              </p>
            </div>
            <div className='grid grid-cols-1 md:grid-cols-3 gap-8'>
              {featuredCakes.map((cake) => (
                <div
                  key={cake.id}
                  className='bg-white rounded-xl shadow-md overflow-hidden transition-transform hover:scale-105 hover:shadow-lg'
                >
                  <div className='relative h-56 overflow-hidden'>
                    <img
                      src={cake.image}
                      alt={cake.name}
                      className='object-cover h-full w-full'
                    />
                  </div>
                  <div className='p-6'>
                    <div className='flex justify-between items-start mb-2'>
                      <h3 className='text-xl font-semibold text-gray-800'>
                        {cake.name}
                      </h3>
                      <p className='text-pink-600 font-bold'>£{cake.price}</p>
                    </div>
                    <p className='text-gray-600 mb-4'>{cake.description}</p>
                    <Button
                      asChild
                      className='w-full bg-yellow-100 hover:bg-yellow-200 text-yellow-800 rounded-full'
                    >
                      <Link to={`/menu/${cake.id}`}>View Details</Link>
                    </Button>
                  </div>
                </div>
              ))}
            </div>
            <div className='text-center mt-10'>
              <Button
                asChild
                variant='outline'
                className='border-pink-300 text-pink-600 hover:bg-pink-50 rounded-full px-8 py-6 text-lg'
              >
                <Link to='/menu'>
                  View All Cakes <ArrowRight className='ml-2 h-5 w-5' />
                </Link>
              </Button>
            </div>
          </div>
        </section>

        {/* Why Choose Us */}
        <section className='py-16 bg-blue-50'>
          <div className='container mx-auto px-4 md:px-6'>
            <div className='text-center mb-12'>
              <h2 className='text-3xl md:text-4xl font-bold text-gray-800 mb-4'>
                Why Choose Golden Crust Bakery?
              </h2>
              <p className='text-gray-600 max-w-2xl mx-auto'>
                We take pride in our commitment to quality, taste, and customer
                satisfaction
              </p>
            </div>
            <div className='grid grid-cols-1 md:grid-cols-3 gap-8'>
              <div className='bg-white p-8 rounded-xl shadow-md text-center'>
                <div className='mx-auto w-16 h-16 bg-pink-100 rounded-full flex items-center justify-center mb-4'>
                  <Cake className='h-8 w-8 text-pink-600' />
                </div>
                <h3 className='text-xl font-semibold text-gray-800 mb-2'>
                  Premium Ingredients
                </h3>
                <p className='text-gray-600'>
                  We use only the finest ingredients to ensure exceptional taste
                  and quality in every bite.
                </p>
              </div>
              <div className='bg-white p-8 rounded-xl shadow-md text-center'>
                <div className='mx-auto w-16 h-16 bg-yellow-100 rounded-full flex items-center justify-center mb-4'>
                  <Star className='h-8 w-8 text-yellow-600' />
                </div>
                <h3 className='text-xl font-semibold text-gray-800 mb-2'>
                  Handcrafted with Love
                </h3>
                <p className='text-gray-600'>
                  Each cake is made with attention to detail and passion by our
                  skilled bakers.
                </p>
              </div>
              <div className='bg-white p-8 rounded-xl shadow-md text-center'>
                <div className='mx-auto w-16 h-16 bg-blue-100 rounded-full flex items-center justify-center mb-4'>
                  <ShoppingBag className='h-8 w-8 text-blue-600' />
                </div>
                <h3 className='text-xl font-semibold text-gray-800 mb-2'>
                  Convenient Ordering
                </h3>
                <p className='text-gray-600'>
                  Easy online ordering and timely delivery to make your
                  celebrations stress-free.
                </p>
              </div>
            </div>
          </div>
        </section>

        {/* Testimonials */}
        <section className='py-16 bg-white'>
          <div className='container mx-auto px-4 md:px-6'>
            <div className='text-center mb-12'>
              <h2 className='text-3xl md:text-4xl font-bold text-gray-800 mb-4'>
                What Our Customers Say
              </h2>
              <p className='text-gray-600 max-w-2xl mx-auto'>
                Don't just take our word for it - hear from our satisfied
                customers
              </p>
            </div>
            <div className='grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8'>
              {reviews.map((review, index) => (
                <div
                  key={index}
                  className='bg-pink-50 p-6 rounded-xl shadow-sm'
                >
                  <div className='flex items-center mb-4'>
                    <div className='mr-4'>
                      <img
                        src={review.img}
                        className='w-12 h-12 rounded-full'
                      ></img>
                    </div>
                    <div>
                      <h4 className='font-semibold text-gray-800'>
                        {review.name}
                      </h4>
                      <div className='flex text-yellow-400'>
                        {[...Array(5)].map((_, count) => (
                          <Star key={count} className='h-4 w-4 fill-current' />
                        ))}
                      </div>
                    </div>
                  </div>
                  <p className='text-gray-600 italic'>{review.comment}</p>
                </div>
              ))}
            </div>
          </div>
        </section>

        {/* Call to Action */}
        <section className='py-16 bg-gradient-to-r from-pink-100 to-yellow-100'>
          <div className='container mx-auto px-4 md:px-6 text-center'>
            <h2 className='text-3xl md:text-4xl font-bold text-gray-800 mb-4'>
              Ready to Order Your Dream Cake?
            </h2>
            <p className='text-gray-700 max-w-2xl mx-auto mb-8'>
              Browse our menu and place your order today. Make your special
              occasion even more memorable with a cake from Golden Crust Bakery.
            </p>
            <Button
              asChild
              className='bg-pink-500 hover:bg-pink-600 text-white rounded-full px-8 py-6 text-lg'
            >
              <Link to='/menu'>
                Order Now <ArrowRight className='ml-2 h-5 w-5' />
              </Link>
            </Button>
          </div>
        </section>
      </div>
    </div>
  );
}
